@@ -139,6 +139,7 @@ class MainWindow(QMainWindow):
         self.menu_Tools.addAction(actions.action_measurement_mode)
         self.menu_Tools.addSeparator()
         self.menu_Tools.addAction(actions.action_normal_mode)
+        self.menu_Tools.addAction(actions.action_cross_section)
 
         self.menu_Help.addAction(actions.action_help)
         self.menu_Help.addAction(actions.action_about)
@@ -177,7 +178,9 @@ class MainWindow(QMainWindow):
         actions.action_slice_blocks.triggered.connect(self.slot_slice_blocks)
         actions.action_detection_mode.triggered.connect(self.slot_detection_mode)
         actions.action_measurement_mode.triggered.connect(self.slot_measurement_mode)
+
         actions.action_normal_mode.triggered.connect(self.slot_normal_mode)
+        actions.action_cross_section.triggered.connect(self.slot_cross_section)
 
         # Help
         actions.action_help.triggered.connect(self.slot_help)
@@ -260,17 +263,23 @@ class MainWindow(QMainWindow):
         if actions.action_autorotate.isChecked():
             self.viewer.set_camera_from_vectors(normal, up)
 
-        # Auto-exit and disconnect
-        self.viewer.set_normal_mode()
-        self.viewer.signal_slice_description.disconnect()
-
     def slot_slice_meshes(self) -> None:
-        def executer(origin, normal) -> None:
+        def executer_standard(origin, normal) -> None:
             slices = self.viewer.slice_meshes(origin, normal)
             self.add_mesh_slices(slices)
 
+        def executer_cross(origin, normal) -> None:
+            self.viewer.cross_section(origin, normal)
+
         def handler(description: dict) -> None:
-            self.handle_slices(description, executer)
+            if self.toolbar.action_collection.action_cross_section.isChecked():
+                self.handle_slices(description, executer_cross)
+            else:
+                self.handle_slices(description, executer_standard)
+
+            # Disconnect
+            self.viewer.set_normal_mode()
+            self.viewer.signal_slice_description.disconnect()
 
         self.viewer.set_slice_mode()
         self.viewer.signal_slice_description.connect(handler)
@@ -283,9 +292,22 @@ class MainWindow(QMainWindow):
         def handler(description: dict) -> None:
             self.handle_slices(description, executer)
 
+            # Disconnect
+            self.viewer.set_normal_mode()
+            self.viewer.signal_slice_description.disconnect()
+
         self.viewer.set_slice_mode()
         self.viewer.signal_slice_description.connect(handler)
 
+    def slot_cross_section(self, status: bool) -> None:
+        self.viewer.set_cross_section(status)
+
+        # Make all meshes either semi-transparent or fully opaque
+        for drawable in self.viewer.get_all_drawables():
+            drawable.alpha *= 0.1 if status else 10.0
+
+        self.viewer.update_all()
+
     def add_mesh_slices(self, slice_list: list) -> None:
         for sliced_meshes in slice_list:
             slices = sliced_meshes.get('vertices')
