@@ -62,6 +62,10 @@ class IntegrableViewer(QOpenGLWidget):
     signal_process_started = Signal()
     signal_process_finished = Signal()
 
+    signal_animation_updated = Signal(int)
+    signal_animation_started = Signal()
+    signal_animation_finished = Signal()
+
     signal_mode_updated = Signal(str)
     signal_fps_updated = Signal(float)
 
@@ -260,19 +264,34 @@ class IntegrableViewer(QOpenGLWidget):
     def set_animated(self, status: bool) -> None:
         self._animated = status
 
-    def animate(self, start, end, method: callable, steps: int = 20) -> callable:
+    def animate(self, start, end, method: callable, **kwargs) -> callable:
+        milliseconds = int(kwargs.get('milliseconds', 300))
+        steps = int(kwargs.get('steps', 20))
+
         timer = QTimer(self)
         linspace = iter(np.linspace(start, end, steps))
+        counter = []
 
-        def animation_per_frame():
+        def start_animation():
+            timer.start(milliseconds / steps)
+            self.signal_animation_started.emit()
+
+        def update_animation():
             try:
                 method(next(linspace))
                 self.update()
-            except StopIteration:
-                timer.stop()
 
-        timer.timeout.connect(animation_per_frame)
-        timer.start(1.0 / 60.0)
+                counter.append(None)
+                self.signal_animation_updated.emit(100.0 * len(counter) / steps)
+            except StopIteration:
+                end_animation()
+
+        def end_animation():
+            timer.stop()
+            self.signal_animation_finished.emit()
+
+        timer.timeout.connect(update_animation)
+        start_animation()
 
     """
     Projections
@@ -550,10 +569,16 @@ class IntegrableViewer(QOpenGLWidget):
         self.update()
 
     def fit_to_screen(self) -> None:
+        bounds = self.bounding_box()
+
+        if bounds is not None:
+            self.fit_to_bounds(*bounds)
+
+    def bounding_box(self) -> tuple or None:
         drawables = [d for d in self.get_all_drawables() if d.is_visible]
 
         if len(drawables) == 0:
-            return
+            return None
 
         min_all = np.inf * np.ones(3)
         max_all = -np.inf * np.ones(3)
@@ -563,7 +588,7 @@ class IntegrableViewer(QOpenGLWidget):
             min_all = np.min((min_all, min_bound), axis=0)
             max_all = np.max((max_all, max_bound), axis=0)
 
-        self.fit_to_bounds(min_all, max_all)
+        return min_all, max_all
 
     """
     Internal methods
@@ -625,7 +650,7 @@ class IntegrableViewer(QOpenGLWidget):
 
         if self.projection_mode == 'perspective':
             self.proj.perspective(self.fov, aspect, 1.0, 100000.0)
-        elif self.projection_mode == 'orthographic':
+        else:  # if self.projection_mode == 'orthographic':
             z = self.off_center[2]
             self.proj.ortho(-z, z, -z / aspect, z / aspect, 0.0, 100000.0)
 
@@ -778,6 +803,14 @@ class IntegrableViewer(QOpenGLWidget):
         results = self.model.detect_mesh_intersection(ray, origin, meshes)
         self.signal_mesh_clicked.emit(results)
 
+    def cross_section(self, origin: np.ndarray, normal: np.ndarray) -> None:
+        self.drawable_collection.update_uniform('CrossSection', 'plane_origin', *origin)
+        self.drawable_collection.update_uniform('CrossSection', 'plane_normal', *normal)
+
+    def set_cross_section(self, status: bool) -> None:
+        for m in self.drawable_collection.filter(MeshGL):
+            m.is_cross_sectionable = status
+
     """
     Controller
     """
